import { PDFDocumentProxy } from "pdfjs-dist";
import React, { Component } from "react";
import { BoundingRect, EventBus as EventBusType, LinkService as LinkServiceType, Viewer as ViewerType } from "../types";
import "pdfjs-dist/web/pdf_viewer.css";
import "../style/pdf_viewer.css";
export declare type Coords = {
    x: number;
    y: number;
};
export declare type Position = {
    boundingRect: BoundingRect;
    rects: Array<BoundingRect>;
    pageNumber: number;
    pageOffset: number;
};
export declare type TextSelectionType = {
    text: string;
    position: Position;
};
export declare type AreaSelectionType = {
    image: string;
    position: Position;
};
export declare type SelectionType = TextSelectionType | AreaSelectionType;
interface PdfViewerProps {
    pdfDocument: PDFDocumentProxy;
    selections?: Array<SelectionType>;
    enableAreaSelection?: (event: React.MouseEvent) => boolean;
    onTextSelection?: (highlightTip?: TextSelectionType) => void;
    onAreaSelection?: (highlightTip?: AreaSelectionType) => void;
}
interface PdfViewerState {
    containerNode?: HTMLDivElement;
    viewer?: ViewerType;
    pageHeights: number[];
    textSelectionEnabled: boolean;
    areaSelection?: {
        originTarget?: HTMLElement;
        start?: Coords;
        end?: Coords;
        position?: Position;
        locked?: boolean;
    };
}
export declare class PdfViewer extends Component<PdfViewerProps, PdfViewerState> {
    state: PdfViewerState;
    eventBus: EventBusType;
    linkService: LinkServiceType;
    pdfContainerRefCallback: (ref: HTMLDivElement) => void;
    getPageOffset: (pageNumber: number) => number;
    containerCoords: (pageX: number, pageY: number) => {
        x: number;
        y: number;
    } | undefined;
    getBoundingRect(start: Coords, end: Coords, pageOffset: number): BoundingRect;
    resize: () => void;
    resetSelections: () => void;
    onSelectionChange: () => void;
    onAreaSelectStart: (event: React.MouseEvent) => void;
    onAreaSelectChange: (event: MouseEvent) => void;
    onAreaSelectEnd: (event: MouseEvent) => void;
    onMouseDown: (event: React.PointerEvent<HTMLDivElement>) => void;
    onMouseMove: (event: MouseEvent) => void;
    onMouseUp: (event: MouseEvent) => void;
    onKeyDown: (event: KeyboardEvent) => void;
    addEventListeners: () => void;
    removeEventListeners: () => void;
    componentDidUpdate(prevProps: PdfViewerProps): void;
    mountDocument: () => void;
    render: () => JSX.Element;
}
export {};
